@@ -54,9 +54,9 @@ def _raster_resample(
     metadata = core_raster._get_basic_metadata_raster(ref)
 
     if isinstance(target_size, (gdal.Dataset, str)):
-        x_res, y_res, x_pixels, y_pixels = utils_gdal._get_raster_size(
-            target_size, target_in_pixels=target_in_pixels
-        )
+        x_res, y_res = utils_gdal._get_raster_size(target_size)
+        x_pixels = None
+        y_pixels = None
     elif target_in_pixels:
         x_res = None
         y_res = None
@@ -222,7 +222,7 @@ def raster_resample(
     utils_base._type_check(overwrite, [bool], "overwrite")
     utils_base._type_check(creation_options, [[str], None], "creation_options")
     utils_base._type_check(dst_nodata, [str, int, float, None], "dst_nodata")
-    utils_base._type_check(dtype, [str, None], "dtype")
+    utils_base._type_check(dtype, [str, None, np.dtype, type(np.int8)], "dtype")
     utils_base._type_check(prefix, [str], "prefix")
     utils_base._type_check(suffix, [str], "postfix")
     utils_base._type_check(add_uuid, [bool], "add_uuid")
