@@ -237,12 +237,14 @@ def _get_basic_metadata_vector(
     bounds_vector_raw = utils_bbox._get_geom_from_bbox(vector_bbox)
     bounds_vector = bounds_vector_raw.ExportToWkt()
 
-    centroid = [(x_max - x_min) / 2, (y_max - y_min) / 2]
-    centroid_latlng = utils_projection._reproject_point(
-        centroid,
-        projection_osr,
-        utils_projection._get_default_projection_osr(),
-    )
+    _centroid = bounds_vector_raw.Centroid()
+    centroid = (_centroid.GetX(), _centroid.GetY())
+    if projection_osr.IsGeographic():
+        centroid_latlng = (centroid[1], centroid[0])
+    else:
+        _centroid_latlng = bounds_latlng.Centroid()
+        centroid_latlng = (_centroid_latlng.GetY(), _centroid_latlng.GetX())
+
 
     metadata = {
         "path": path,
@@ -874,3 +876,118 @@ def vector_reset_fids(
         return output
 
     return output[0]
+
+
+def vector_from_bbox(
+    bbox: List[Union[float, int]],
+    projection: Union[str, osr.SpatialReference, None] = None,
+    out_path: Optional[str] = None,
+) -> str:
+    """
+    Creates a vector from a bounding box.
+    
+    Parameters
+    ----------
+    bbox : List[float, int]
+        The bounding box to create the vector from. Must be in the format [x_min, x_max, y_min, y_max].
+
+    projection : Union[str, osr.SpatialReference, None], optional
+        The projection of the bounding box. If None, the default (latlng) projection is used. Default: None.
+
+    out_path : Optional[str], optional
+        The path to the output vector. If None, will create a new file in the same directory as the input vector. Default: None.
+    """
+    assert utils_bbox._check_is_valid_bbox(bbox), "bbox is not a valid bounding box."
+
+    if projection is None:
+        proj = utils_projection._get_default_projection_osr()
+    else:
+        proj = utils_projection.parse_projection(projection)
+
+    if out_path is None:
+        out_path = utils_path._get_temp_filepath("temp_bbox.gpkg", add_timestamp=True, add_uuid=True)
+    
+    if not utils_path._check_is_valid_output_filepath(out_path):
+        raise ValueError(f"Invalid output path: {out_path}")
+    
+    driver_name = utils_gdal._get_vector_driver_name_from_path(out_path)
+    driver = ogr.GetDriverByName(driver_name)
+
+    datasource = driver.CreateDataSource(out_path)
+    layer = datasource.CreateLayer("bbox", geom_type=ogr.wkbPolygon, srs=proj)
+    feature = ogr.Feature(layer.GetLayerDefn())
+    feature.SetGeometry(utils_bbox._get_geom_from_bbox(bbox))
+    
+    layer.CreateFeature(feature)
+    layer.SyncToDisk()
+
+    datasource = None
+    layer = None
+    feature = None
+
+    return out_path
+
+
+def vector_from_points(
+    points: List[List[Union[float, int]]],
+    projection: Union[str, osr.SpatialReference, None] = None,
+    out_path: Optional[str] = None,
+    reverse_xy_order: bool = False,
+) -> str:
+    """
+    Creates a point vector from a list of points.
+    
+    Parameters
+    ----------
+    points : List[List[float, int]]
+        The points to create the vector from. Must be in the format [[x1, y1], [x2, y2], ...].
+
+    projection : Union[str, osr.SpatialReference, None], optional
+        The projection of the points. If None, the default (latlng) projection is used. Default: None.
+
+    out_path : Optional[str], optional
+        The path to the output vector. If None, will create a new file in the same directory as the input vector. Default: None.
+    """
+    assert isinstance(points, list), "points must be a list."
+    assert len(points) > 0, "points must have at least one point."
+    for point in points:
+        assert isinstance(point, list), "points must be a list of lists."
+        assert len(point) == 2, "points must be a list of lists of length 2."
+
+    if projection is None:
+        proj = utils_projection._get_default_projection_osr()
+    else:
+        proj = utils_projection.parse_projection(projection)
+
+    if out_path is None:
+        out_path = utils_path._get_temp_filepath("temp_points.gpkg", add_timestamp=True, add_uuid=True)
+    
+    if not utils_path._check_is_valid_output_filepath(out_path):
+        raise ValueError(f"Invalid output path: {out_path}")
+    
+    driver_name = utils_gdal._get_vector_driver_name_from_path(out_path)
+    driver = ogr.GetDriverByName(driver_name)
+
+    datasource = driver.CreateDataSource(out_path)
+    layer = datasource.CreateLayer("points", geom_type=ogr.wkbPoint, srs=proj)
+    layer_defn = layer.GetLayerDefn()
+
+    for point in points:
+        feature = ogr.Feature(layer_defn)
+        geom = ogr.Geometry(ogr.wkbPoint)
+        if reverse_xy_order:
+            geom.AddPoint(point[1], point[0])
+        else:
+            geom.AddPoint(point[0], point[1])
+        feature.SetGeometry(geom)
+        
+        layer.CreateFeature(feature)
+        feature = None
+
+    layer.GetExtent()
+    layer.SyncToDisk()
+
+    datasource = None
+    layer = None
+
+    return out_path
